#[repr(i32)]pub enum GenericComparator {
Eq = 0,
Ne = 1,
ArrayContains = 2,
ArrayNotContains = 3,
}Expand description
A leaf-node Where clause may compare a string, int, or float to a single
value of the same type. These comparators apply to all three of those types.
Variants
Eq = 0
Ne = 1
ArrayContains = 2
Array contains operators: check if an array metadata field contains (or does not contain) a specific scalar value. NOTE: This is called ARRAY_CONTAINS only in proto since there are conflicting names in scope. Elsewhere, it is called CONTAINS and NOT_CONTAINS.
ArrayNotContains = 3
Implementations
Sourceimpl GenericComparator
impl GenericComparator
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.