#[repr(i32)]pub enum ReadLevel {
IndexAndWal = 0,
IndexOnly = 1,
IndexAndBoundedWal = 2,
}Expand description
ReadLevel specifies which data sources to read from during queries. This affects consistency vs performance tradeoffs.
Variants
IndexAndWal = 0
Read from both the index and the write-ahead log (default). Provides full consistency with all committed writes visible.
IndexOnly = 1
Read only from the index, skipping the write-ahead log. Provides eventual consistency - recent uncommitted writes may not be visible.
IndexAndBoundedWal = 2
Read from the index and up to a server-configured number of write-ahead log entries. Provides a consistent prefix of the WAL with bounded query latency: recently committed writes beyond the limit may not be visible.
Implementations
Sourceimpl ReadLevel
impl ReadLevel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.