GetCollectionsRequest

Struct GetCollectionsRequest 

pub struct GetCollectionsRequest {
    pub id: Option<String>,
    pub name: Option<String>,
    pub tenant: String,
    pub database: String,
    pub limit: Option<i32>,
    pub offset: Option<i32>,
    pub ids_filter: Option<CollectionIdsFilter>,
    pub include_soft_deleted: Option<bool>,
    pub topology_name: Option<String>,
}

Fields

id: Option<String>name: Option<String>tenant: Stringdatabase: Stringlimit: Option<i32>offset: Option<i32>ids_filter: Option<CollectionIdsFilter>include_soft_deleted: Option<bool>topology_name: Option<String>

Implementations

Source

impl GetCollectionsRequest

pub fn id(&self) -> &str

Returns the value of id, or the default value if id is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn limit(&self) -> i32

Returns the value of limit, or the default value if limit is unset.

pub fn offset(&self) -> i32

Returns the value of offset, or the default value if offset is unset.

pub fn include_soft_deleted(&self) -> bool

Returns the value of include_soft_deleted, or the default value if include_soft_deleted is unset.

pub fn topology_name(&self) -> &str

Returns the value of topology_name, or the default value if topology_name is unset.