pub struct InvocationStatusResult {
pub status: i32,
pub current_completion_offset: i64,
}Fields
status: i32current_completion_offset: i64Implementations
Sourceimpl InvocationStatusResult
impl InvocationStatusResult
Sourcepub fn status(&self) -> InvocationStatus
pub fn status(&self) -> InvocationStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: InvocationStatus)
pub fn set_status(&mut self, value: InvocationStatus)
Sets status to the provided enum value.