pub enum SparseIndexAlgorithm {
Wand,
MaxScore,
}Expand description
Sparse vector index algorithm.
Controls which posting list format and query engine are used for sparse vector search within a collection.
Variants