pub struct Segment {
pub id: SegmentUuid,
pub type: SegmentType,
pub scope: SegmentScope,
pub collection: CollectionUuid,
pub metadata: Option<Metadata>,
pub file_path: HashMap<String, Vec<String>>,
}Fields
id: SegmentUuidtype: SegmentTypescope: SegmentScopecollection: CollectionUuidmetadata: Option<Metadata>file_path: HashMap<String, Vec<String>>Implementations
Sourceimpl Segment
impl Segment
pub fn get_shards(&self) -> Result<Vec<SegmentShard>, SegmentShardError>
pub fn prefetch_supported(&self) -> bool
Sourcepub fn filepaths_to_prefetch(&self, shard_index: Option<u32>) -> Vec<String>
pub fn filepaths_to_prefetch(&self, shard_index: Option<u32>) -> Vec<String>
Returns the file paths that should be prefetched for this segment. If shard_index is None, returns the active shard’s file paths. If shard_index is Some, returns only the file paths for that shard.
Sourcepub fn num_shards(&self) -> Result<usize, SegmentShardError>
pub fn num_shards(&self) -> Result<usize, SegmentShardError>
Returns the number of shards for this segment. Derives from the length of file_path Vecs (all must be equal per the shard count invariant). Returns 1 if no file paths are present.
pub fn extract_prefix_and_id(path: &str) -> Result<(&str, Uuid), Error>
pub fn construct_prefix_path( &self, tenant: &str, database_id: &DatabaseUuid, ) -> String